@@ -1,4 +1,4 @@
-package Pcore::DBH::Query::pgsql;    ## no critic qw[NamingConventions::Capitalization]
+package Pcore::DBH::Query::pgsql;
 
 use Pcore -class;
 use DBD::Pg qw[:async];
